@@ -106,9 +106,18 @@ NULL
 #' }
 #' @export
 s_estimate <- function(object = NA){
-  if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
+  if (!inherits(object, c("regarima","regarima_spec","SA","SA_spec")))
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$estimate)
   } else if (inherits(object, "regarima_spec")){
@@ -131,6 +140,15 @@ s_transform <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$transform)
   } else if (inherits(object, "regarima_spec")){
@@ -149,10 +167,19 @@ s_transform <- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_usrdef<- function(object = NA){
+s_usrdef <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$regression$userdef$specification)
   } else if (inherits(object, "regarima_spec")){
@@ -171,10 +198,19 @@ s_usrdef<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_preOut<- function(object = NA){
+s_preOut <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$regression$userdef$outliers)
   } else if (inherits(object, "regarima_spec")) {
@@ -189,10 +225,19 @@ s_preOut<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_preVar<- function(object = NA){
+s_preVar <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$regression$userdef$variables)
   } else if (inherits(object, "regarima_spec")){
@@ -207,10 +252,19 @@ s_preVar<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_td<- function(object = NA){
+s_td <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$regression$trading.days)
   } else if (inherits(object, "regarima_spec")){
@@ -229,10 +283,19 @@ s_td<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_easter<- function(object = NA){
+s_easter <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$regression$easter)
   } else if (inherits(object, "regarima_spec")){
@@ -251,10 +314,19 @@ s_easter<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_out<- function(object = NA){
+s_out <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$outliers)
   } else if (inherits(object, "regarima_spec")){
@@ -272,10 +344,19 @@ s_out<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_arima<- function(object = NA){
+s_arima <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$arima$specification)
   } else if (inherits(object, "regarima_spec")){
@@ -294,10 +375,19 @@ s_arima<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_arimaCoef<- function(object = NA){
+s_arimaCoef <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$arima$coefficients)
   } else if (inherits(object, "regarima_spec")){
@@ -315,6 +405,15 @@ s_fcst <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$forecast)
   }else if (inherits(object, "regarima_spec")){
@@ -331,10 +430,19 @@ s_fcst <- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_span<- function(object = NA){
+s_span <- function(object = NA){
   if (inherits(object, c("regarima","regarima_spec","SA","SA_spec"))==FALSE)
     stop("use only with \"regarima\", \"regarima_spec\", \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
+  if (inherits(object, "X13") &&
+      (
+        (inherits(object, "regarima_spec") && is.null(object$estimate)) ||
+        (inherits(object, "regarima") && is.null(object$specification$estimate)) ||
+        (inherits(object, "SA_spec") && is.null(object$regarima$estimate)) ||
+        (inherits(object, "SA") && is.null(object$regarima$specification$estimate))
+      ))
+    return(NULL)
+
   if (inherits(object, "regarima")){
     return(object$specification$span)
   } else if (inherits(object, "regarima_spec")){
@@ -349,7 +457,7 @@ s_span<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_x11<- function(object = NA){
+s_x11 <- function(object = NA){
   if (inherits(object, c("SA","SA_spec"))==FALSE)
     stop("use only with \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
@@ -364,7 +472,7 @@ s_x11<- function(object = NA){
 #' @rdname specification
 #' @name specification
 #' @export
-s_seats<- function(object = NA){
+s_seats <- function(object = NA){
   if (inherits(object, c("SA","SA_spec"))==FALSE)
     stop("use only with \"SA\" and \"SA_spec\" objects", call. = FALSE)
 
