@@ -1108,7 +1108,7 @@ spec_TRAMO_r2jd <- function(rspec = NA, jdspec =NA){
     .jcall(jtd,"V","setOption","UserDefined")
   }else{
     if (td[5]==0) {
-      .jcall(jtd,"V","setW",as.integer(td[5]))
+#      .jcall(jtd,"V","setW",as.integer(td[5]))
       .jcall(jtd,"V","setTradingDays",as.character(td[3]))
     }else{
       .jcall(jtd,"V","setTradingDays",as.character(td[3]))
@@ -1191,9 +1191,9 @@ specX11_r2jd <- function(rspec = NA, jdspec = NA , freq = NA){
   .jcall(jx11,"V","setLSigma",as.numeric(x11[["x11.lsigma"]]))
   .jcall(jx11,"V","setUSigma",as.numeric(x11[["x11.usigma"]]))
   if (x11[["x11.trendAuto"]]) {
-    .jcall(jx11,"V","setTrendMA",as.integer(x11[["x11.trendma"]]))
+    .jcall(jx11,"V","setAutoTrendMA",as.logical(TRUE))
   }else{
-    .jcall(jx11,"V","setAutoTrendMA",as.logical(x11[["x11.trendAuto"]]))
+    .jcall(jx11,"V","setAutoTrendMA",as.logical(FALSE))
     .jcall(jx11,"V","setTrendMA",as.integer(x11[["x11.trendma"]]))
   }
   .jcall(jx11,"V","setFreq", as.integer(freq))
